@@ -1,11 +1,15 @@
 """ Utils functions for models """
-from datetime import datetime
+import logging
+from datetime import datetime, timezone
+
+logger = logging.getLogger(__name__)
 
 
 def datetime_must_have_timezone(cls, v: datetime):
     """Enforce that this variable must have a timezone"""
     if v.tzinfo is None:
-        raise ValueError(f"{v} must have a timezone, for cls {cls}")
+        logger.debug(f"{v} must have a timezone, for cls {cls}." f"So we are going to add UTC ")
+        v = v.replace(tzinfo=timezone.utc)
     return v
 
 
