@@ -25,13 +25,15 @@ def nwp_irradence_simple_run_all_batches(
     """Run model for all batches"""
 
     # time now rounded down by 30 mins
-    t0_datetime_utc = floor_30_minutes_dt(datetime.utcnow())
+    t0_datetime_utc = floor_30_minutes_dt(datetime.now(timezone.utc))
+    logger.info(f"Making forecasts for {t0_datetime_utc=}")
 
     # make confgiruation
     if configuration_file is None:
         configuration_file = os.path.join(
             os.path.dirname(nowcasting_forecast.__file__), "config", "mvp_v0.yaml"
         )
+    logger.debug(f"Loading configuration {configuration_file}")
     configuration = load_yaml_configuration(filename=configuration_file)
 
     # make dataloader
@@ -43,10 +45,12 @@ def nwp_irradence_simple_run_all_batches(
         logger.debug(f"Running batch {i} into model")
 
         batch = next(dataloader)
-        forecasts = forecasts + nwp_irradence_simple_run_one_batch(batch=batch)
+        forecasts = forecasts + nwp_irradence_simple_run_one_batch(batch=batch, batch_idx=i)
 
     # select first 338 forecast
     if len(forecasts) > 338:
+        logger.debug('There are more than 338 forecasts, so just taking the first 338. '
+                     'This can happen due to rounding up the examples to fit in batches')
         forecasts = forecasts[0:338]
 
     # convert to sql objects
@@ -55,10 +59,12 @@ def nwp_irradence_simple_run_all_batches(
     # add national forecast # TODO make this from the forecast
     forecasts_sql.append(make_fake_national_forecast(t0_datetime_utc=t0_datetime_utc))
 
+    logger.info(f"Made {len(forecasts_sql)} forecasts")
+
     return forecasts_sql
 
 
-def nwp_irradence_simple_run_one_batch(batch: Union[dict, Batch]) -> List[Forecast]:
+def nwp_irradence_simple_run_one_batch(batch: Union[dict, Batch], batch_idx: int) -> List[Forecast]:
     """Run model for one batch"""
 
     # make sure its a Batch object
@@ -69,7 +75,7 @@ def nwp_irradence_simple_run_one_batch(batch: Union[dict, Batch]) -> List[Foreca
     irradence_mean = nwp_irradence_simple(batch)
 
     # set up forecasts fields
-    forecast_creation_time = datetime.now(timezone.utc)
+    forecast_creation_time = datetime.now(tz=timezone.utc)
 
     # TODO make input data from actual data
     input_data_last_updated = make_fake_input_data_last_updated()
@@ -78,10 +84,14 @@ def nwp_irradence_simple_run_one_batch(batch: Union[dict, Batch]) -> List[Foreca
     for i in range(batch.metadata.batch_size):
 
         # TODO make proper location
-        location = Location(gsp_id=1, label="fake")
+        gsp_id = i + batch_idx * batch.metadata.batch_size
+        location = Location(gsp_id=gsp_id, label=f"GSP_{gsp_id}")
+
+        # add timezone
+        target_time = batch.metadata.t0_datetime_utc[i].replace(tzinfo=timezone.utc)
 
         forecast_value = ForecastValue(
-            target_time=batch.metadata.t0_datetime_utc[i],
+            target_time=target_time,
             expected_power_generation_megawatts=irradence_mean,
         )
 
